@@ -63,9 +63,10 @@ class TimeStatistics(SimpleStatistics):
             if hasattr(self, "notification_url"):
                 url = self.notification_url + "?time=%s&agents=%s&conf=%s" % (
                     time.time() - self.start, os.environ['AGENTS'], sys.argv[1])
-            logger.info(url)
-            urllib2.urlopen(url)
-
+                logger.info(url)
+                urllib2.urlopen(url)
+            logger.debug(self.history)
+            logger.debug("best genotype: %s", max(agents, key=lambda a: a.get_fitness).get_best_genotype())
         except:
             logging.exception("")
 
