@@ -9,23 +9,22 @@ from pyage.core.agent.aggregate import AggregateAgent
 from pyage.core.emas import EmasService
 from pyage.core.locator import  GridParentLocator
 from pyage.core.migration import Pyro4Migration
-from pyage.core.statistics import   NotificationStatistics
-from pyage.core.stop_condition import StepLimitStopCondition
+from pyage.core.stats.distributed import GlobalStepStatistics
+from pyage.core.stop_condition import GlobalMinimumFitnessStopCondition
 from pyage.solutions.evolution.crossover import   SinglePointCrossover
 from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
 from pyage.solutions.evolution.initializer import  float_emas_initializer
 from pyage.solutions.evolution.mutation import  UniformFloatMutation
 
-
 logger = logging.getLogger(__name__)
 
 agents_count = int(os.environ['AGENTS'])
 logger.debug("EMAS, %s agents", agents_count)
 agents = unnamed_agents(agents_count, AggregateAgent)
 
-stop_condition = lambda: StepLimitStopCondition(1000)
+stop_condition = lambda: GlobalMinimumFitnessStopCondition(-100)
 
-aggregated_agents = lambda: float_emas_initializer(40, energy=100, size=100, lowerbound=-10, upperbound=10)
+aggregated_agents = lambda: float_emas_initializer(40, energy=100, size=50, lowerbound=-10, upperbound=10)
 
 emas = EmasService
 
@@ -48,5 +47,4 @@ ns_hostname = lambda: os.environ['NS_HOSTNAME']
 pyro_daemon = Pyro4.Daemon()
 daemon = lambda: pyro_daemon
 
-stats = NotificationStatistics
-notification_url = lambda: 'http://student.agh.edu.pl/~kmaciej/pyage.php'
\ No newline at end of file
+stats = GlobalStepStatistics
\ No newline at end of file
